Tutorials
==========

Here there is a small number of small tutorials to get you going with SatMAD. You can find the interactive
Jupyter notebook versions of these at the
`project repository <https://github.com/egemenimre/satmad/tree/master/docs/tutorials>`_.

In addition to the tutorials in this section, there is a repository of how-to guides and analyses in a
dedicated project called SatMAD Applications,
`available at Github <https://github.com/egemenimre/satmad_applications>`_ (for Jupyter notebooks)
and `in plain document format <https://satmad-applications.readthedocs.io/>`_.

.. toctree::
    :maxdepth: 1

    tutorials/satmad_first_steps.ipynb
    tutorials/numerical_prop_1.ipynb
    tutorials/numerical_prop_2.ipynb
    tutorials/sso_analysis.ipynb
